// The Vue build version to load with the `import` command
// (runtime-only or standalone) has been set in webpack.base.conf with an alias.

import es6promise from "es6-promise/auto";
import objassign from 'es6-object-assign/auto';
import LOCATOR_CONSTANTS from '@/services/constants'
import { MediaQueries } from 'vue-media-queries';

import VueAnalytics from 'vue-analytics';

import Vue from "vue";
import Vuex from 'vuex'

import App from "./App";
import router from "./router";

import VeeValidate from "vee-validate";

import * as VueGoogleMaps from "vue2-google-maps";
import tenancy from './mixins/tenancy.js';
import VueAwesomeSwiper from 'vue-awesome-swiper';
import axios from "axios";
import recorder from './mixins/recorder.js';
import store from '@/store/'
import VueScrollTo from 'vue-scrollto'
import vueCustomElement from 'vue-custom-element';



Vue.config.productionTip = false;
Vue.config.API_ENDPOINT = process.env.API_ENDPOINT;
Vue.config.STATIC_ROOT = process.env.STATIC_ROOT;
Vue.config.GA_ACCOUNT = process.env.GA_ACCOUNT;
Vue.config.LOCATOR_TENANT = window.LOCATOR_TENANT;
Vue.use(VeeValidate);
Vue.use(VueScrollTo);
Vue.use(vueCustomElement);

const mediaQueries = new MediaQueries();

Vue.use(mediaQueries);

var gaConfig = [Vue.config.LOCATOR_TENANT.GA_KEY];

if (Vue.config.LOCATOR_TENANT.GA_KEY_2) {
    gaConfig.push(Vue.config.LOCATOR_TENANT.GA_KEY_2);
}
Vue.use(LOCATOR_CONSTANTS);

Vue.use(VueGoogleMaps, {
    load: {
        key: Vue.config.LOCATOR_TENANT.GOOGLE_MAPS_KEY,
        libraries: ["places", "geometry"] // This is required if you use the Autocomplete plugin
        // OR: libraries: 'places,drawing'
        // OR: libraries: 'places,drawing,visualization'
        // (as you require)
    }
});


Vue.use(VueAnalytics, {
    id: gaConfig,
    router: router,
    autoTracking: {
        pageviewTemplate(route) {
            return {
                page: 'ecp-locator' + route.path,
                title: document.title,
                location: window.location.href
            }
        }
    },
    fields: {
        "appName": Vue.config.LOCATOR_TENANT.LOCATOR_NAME
    },
    ready() {
        try {
            window.ecpLocatorSessionId = ga.getAll()[0].get('clientId');
        }
        catch(error) {
            window.ecpLocatorSessionId = "session" + Math.random() * 10000;
        }

    }
});


Vue.use(VueAwesomeSwiper);


var instance = axios.create({
    baseURL: Vue.config.API_ENDPOINT,
    timeout: 20000,
    headers: { "X-Custom-Header": "ECP Locator" }
});


window.axios = instance;
Vue.mixin(tenancy);
Vue.mixin(recorder);

/* eslint-disable no-new */
new Vue({
    el: "#ecplocatornetinject",
    router,
    store,
    template: "<App/>",
    components: { App },
    mediaQueries: mediaQueries
});
