import Vue from "vue";
import Router from "vue-router";
import Home from "@/components/Home";
import Result from "@/components/result/Result";
import Practice from "@/components/practice/Practice";
Vue.use(Router);

function toggle(className, display){
    var elements = document.getElementsByClassName(className);
    for (var i = 0; i < elements.length; i++){
        if (display){
            elements[i].style.display = "block";
        }
        else{
            elements[i].style.display = "none";
        }
        }    
}

function resultRouteProps(route) {
    return {
        searchCriteriaInitial: {
            miles: route.query.miles || 10,
            insurance: route.query.insurance || "Private Pay Only",
            address: route.query.address,
            filters: Array.isArray(route.query.filters) ? route.query.filters : route.query.filters ? [ route.query.filters] : [],
            offertype: route.query.offertype || 'none'
        }
    }
}

const router = new Router({

    routes: [
        {
            path: "/",
            name: "home",
            component: Home
        },
        {
            path: "/result",
            name: "result",
            component: Result,
            props: resultRouteProps
        },
        {
            path: "/practice/:practiceIdentifier",
            name: "practice",
            component: Practice,
            props: route => ({
                practiceIdentifier: route.params.practiceIdentifier,
                searchFromLocation: {
                    lat: route.query.lat,
                    lng: route.query.lng
                }
            })
        },

    ]
});

router.beforeEach((to, from, next) => {
  
    if (to && to.name === 'home'){
        toggle("locator_show_home", true);
        toggle("locator_show_result", false);
        toggle("locator_show_practice", false);
    }

    if (to && to.name === 'result'){
        toggle("locator_show_home", false);
        toggle("locator_show_result", true);
        toggle("locator_show_practice", false);
    }

    if (to && to.name === 'practice'){
        toggle("locator_show_home", false);
        toggle("locator_show_result", false);
        toggle("locator_show_practice", true);
    }

    next();
});

router.afterEach((to, from) => {
    if (to && to.name === "practice") {
        window.scrollTo(0, 0);
    }


   
});

export default router;
