import * as types from './mutation_types';
import api from '../api';
import SEARCH_STATE from '../services/constants';
import recorder from '../mixins/recorder.js';
import Vue from 'vue'

function callSearchAPI(commit, getters, recordToGA) {
  let criteria = getters.searchCriteria;
  api.search(criteria, (result) => {
    commit(types.RECEIVE_SEARCH_RESULT, result.data);
    commit(types.SELECT_PRACTICE, null);

    let results = getters.searchResult;
    if (results.totalResults === 0) {
      commit(types.SET_SEARCH_ACTION_STATE, SEARCH_STATE.STATE_NO_RESULTS);
      if (recordToGA){
      recorder.methods.recordSearchEvent(results.criteria, 0);
      }
    }
    else {
      commit(types.SET_SEARCH_ACTION_STATE, SEARCH_STATE.STATE_HAVE_RESULTS);
      if (recordToGA){
        recorder.methods.recordSearchEvent(results.criteria, results.resultCount);
      }
    
      for (let p of results.practices) {
        recorder.methods.recordPracticeEvent(recorder.data().trackedEvents.SEARCHRESULT_VIEWED, p
        );
      }
    }
  });
} 

export const search = ({ commit, getters }, { miles, address, insurance, filters, isUltimateOffer }) => {
  if (!getters.mapsLoaded){
    return;
  }
  commit(types.SET_SEARCH_ACTION_STATE, SEARCH_STATE.STATE_LOADING);
  api.geoCode(address = Vue.config.LOCATOR_TENANT.country ? address + " " + Vue.config.LOCATOR_TENANT.country: address, (status, latitude, longitude, postalCode) => {
    if (status === google.maps.GeocoderStatus.OK) {
      var criteria = getters.searchCriteria;
      criteria.page = 1;
      criteria.locatorKey = Vue.config.LOCATOR_TENANT.TENANT_KEY;
      criteria.isUltimateOffer = isUltimateOffer;
      criteria.miles = miles;
      criteria.insurance = insurance;
      criteria.latitude = latitude;
      criteria.longitude = longitude;
      criteria.filters = filters || [];
      criteria.zipCode = postalCode;
      commit(types.MUTATE_SEARCH_CRITERIA, criteria);
      callSearchAPI(commit, getters, true)
    }
    else {
      commit(types.SET_SEARCH_ACTION_STATE, SEARCH_STATE.STATE_ADDRESS_NOT_FOUND);
      //mutate search result to failure
    }
  })
}

export const markMapsLoaded = ({ commit }) => {
  commit(types.MARK_MAPS_LOADED);
}

export const pageNext = ({ commit, getters }) => {
  var criteria = getters.searchCriteria;
  criteria.page += 1;
  commit(types.MUTATE_SEARCH_CRITERIA, criteria);
  callSearchAPI(commit, getters, false);
}
export const pagePrevious = ({ commit, getters }) => {
  var criteria = getters.searchCriteria;
  criteria.page -= 1;
  commit(types.MUTATE_SEARCH_CRITERIA, criteria);
  callSearchAPI(commit, getters, false);
}

export const selectPractice = ({ commit }, practice) => {
  commit(types.SELECT_PRACTICE, practice);
}